<template>
  <section
    :class="{ ['color' + parts.shop_color]: true, ['layout' + parts.shop_style]: true }"
    class="parts">
    <div class="shop-html">
      <div class="shop-body">
        <template v-if="parts.shop_style == 1">
          <div class="headerwidthcontainer">
            <div id="shopname">{{ parts.name }}</div>
            <div id="yatlogo">
              <img
                id="yatlogoimg"
                :src="logo"
                width="98"
                height="81">
            </div>
            <div id="banner">
              <p>{{ parts.description }}</p>
            </div>
          </div>
          <div class="contentwidthcontainer">
            <div
              v-if="parts.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'parts_and_servicemain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'parts_and_servicemain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'parts_and_servicerepair'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'parts_and_servicerepair')}"
                    class="tab">Make Repairs
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'parts_and_serviceaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'parts_and_serviceaccounting')}"
                    class="tab">Accounting
                  </a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
            <router-view
              :has-swiper="hasSwiper"
              :all-repaired-vehicles="allRepairedVehicles"
              :shop="parts"
              @simple-one="simpleOne"
              @simple-two="simpleTwo"
              @busy-one="busyOne"
              @busy-two="busyTwo"
              @repair-complete="getRepairedVehicles" />
          </div>

        </template>
        <template v-if="parts.shop_style == 2">
          <div class="fullwidthcontainer ps2head">
            <div class="headerwidthcontainer">
              <div id="shopname">{{ parts.name }}</div>
              <div id="yatlogo">
                <img
                  id="yatlogoimg"
                  :src="logo"
                  width="98"
                  height="81">
              </div>
            </div>
          </div>
          <div class="contentwidthcontainer">
            <div id="menu">
              <div class="screw screwleft"/>
              <div class="screw screwright"/>
              <div v-if="parts.admin">
                <ul
                  id="nav"
                  class="tab-buttons">
                  <router-link
                    :to="{name: 'parts_and_servicemain'}"
                    tag="li">
                    <a
                      :class="{selected: (this.$route.name === 'parts_and_servicemain')}"
                      class="tab">Home
                    </a>
                  </router-link>
                  <router-link
                    :to="{name: 'parts_and_servicerepair'}"
                    tag="li">
                    <a
                      :class="{selected: (this.$route.name === 'parts_and_servicerepair')}"
                      class="tab">Make Repairs
                    </a>
                  </router-link>
                  <router-link
                    :to="{name: 'parts_and_serviceaccounting'}"
                    tag="li">
                    <a
                      :class="{selected: (this.$route.name === 'parts_and_serviceaccounting')}"
                      class="tab">Accounting
                    </a>
                  </router-link>
                  <div class="clear"/>
                </ul>
              </div>
            </div>
            <div class="tabs">
              <router-view
                :shop="parts"
                :all-repaired-vehicles="allRepairedVehicles"
                :has-swiper="hasSwiper"
                class="tab selected"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"
                @repair-complete="getRepairedVehicles" />
            </div>
          </div>
        </template>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";

export default {
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      parts: {},
      hasSwiper: app.computerSettings.swiper,
      allRepairedVehicles: []
    };
  },
  created: function () {
    this.getData();
    this.getRepairedVehicles();
  },
  beforeMount: function () {
    this.$router.push({name: 'parts_and_servicemain'});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/parts_and_service/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.parts = Response;
            app.Message( "Found parts & service shop!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.parts.shop_style = 1;
      this.parts.shop_color = 1;
    },
    simpleTwo() {
      this.parts.shop_style = 1;
      this.parts.shop_color = 2;
    },
    busyOne() {
      this.parts.shop_style = 2;
      this.parts.shop_color = 1;
    },
    busyTwo() {
      this.parts.shop_style = 2;
      this.parts.shop_color = 2;
    },
    getRepairedVehicles() {
      app.session.SetSession()
        .then( () => {
          app.api.Get(`parts_and_service/getrepairedvehicles/${app.session.data.id}`)
            .then(Response => this.allRepairedVehicles = Response)
            .catch(Response => console.log(Response.error));
        })
        .catch( x => app.Message( x.error, "error" ) );
    }
  },


};
</script>

<style lang="less">
.parts.layout1.color1 {
  /* Parts and Service common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/parts/partsandservicewallbg2.jpg);
    @bgcontentimage2: url(/images/shop/parts/partsandservicewallbg.jpg);
  @bgimage: url(/images/shop/parts/partsandservicebannerbg.png);
  /*@textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;*/

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:96.7rem 33.5rem;
  }
  .fullback() {
    background-image: @bgcontentimage2;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 47.9rem;
    // height:45.9rem;
  }
  //color1
  @shoptitlecolor: #ffffff;
  @logoborder: 0.5rem solid #2e55b0;
  @shopdesccolor: #b33636;
  @homemsgcolor: #7f0000;
  @activetabcolor: #1d4091;
  @navbgcolor: #2e55b0;
  @tabfontcolor: #ffffff;
  @hometxtcolor: #337399;
  @shopbackgroundcolor: #2e55b0;
  @successcolor: #6ecaff;
  @buttoncolor: white;

  @import "../../shared.less";
  @import "./partsLayout1.less";

}

</style>

<style lang="less">
.parts.layout1.color2 {
  /* Parts and Service common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/parts/partsandservicewallbg.jpg);
  @bgimage: url(/images/shop/parts/partsandservicebannerbg.png);
  /*@textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;*/

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgimage;
    background-repeat:no-repeat;
    background-position:center 0rem;
    background-size:96.7rem 33.5rem;
  }
  .fullback() {
    background-image: @bgcontentimage;
    background-repeat:repeat;
    background-position:center 0rem;
    background-size:30rem 47.9rem;
    // height:45.9rem;
  }
  @shoptitlecolor: #000000;
  @logoborder: 0.5rem solid #fccb42;
  @shopdesccolor: #227eb1;
  @homemsgcolor: #144a68;
  @activetabcolor: #dbaf34;
  @navbgcolor: #fccb42;
  @tabfontcolor: #000000;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @successcolor: #fccb42;
  @buttoncolor: black;
  @import "../../shared.less";
  @import "./partsLayout1.less";

}

</style>

<style lang="less">
.parts.layout2.color1 {
  /* Parts and Service common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/parts/ps2bodybg.jpg);
  @bgimage: url(/images/shop/parts/ps2bodybg.jpg);
  /*@textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;*/

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgimage;
    background-repeat:repeat-x;

  }
  .fullback() {
    background-image: @bgcontentimage;
    background-repeat:repeat-x;
    background-position:center 0rem;
    background-size:30rem 47.9rem;
    height:45.9rem;
  }
  //color1
  @shoptitlecolor: #fccb42;
  @logoborder: 0.5rem solid #fccb42;
  @shopdesccolor: #b33636;
  @homemsgcolor: #02429c;
  @mainfontcolor: #02429c;
  @thcolor:#FCCB42;
  @activetabcolor: #fccb42;
  @navbgcolor: #2e55b0;
  @tabfontcolor: #ffffff;
  @hometxtcolor: #337399;
  @shopbackgroundcolor: #2e55b0;
  @successcolor: white;
  @buttoncolor: white;
  @buttonbgcolor: #f71b00;
  @wrenchimage: url(/images/shop/parts/ps2wrench.png);
  @spinnerimage: url(/images/shop/shared/spinner-blue.png) no-repeat;
    .navstyle() {
    background-color: none;
  line-height: 1.5rem;
  padding: 0.1rem 1.5rem .2rem;
  border:none;
  text-decoration:none;
  }
  .activestyle() {
    color:#fccb42;
  text-shadow: -0.1rem -0.1rem 0rem rgba(0,0,0,.7);
  border:none;
  background-color:none;
  }
  @import "../../shared.less";
  @import "./partsLayout2.less";
}

</style>

<style lang="less">
.parts.layout2.color2 {
  /* Parts and Service common */
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @bgcontentimage: url(/images/shop/parts/ps2bodybg.jpg);
  @bgimage: url(/images/shop/parts/ps2bodybg.jpg);
  /*@textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;*/

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
    background-color: #ffa400;
    border-color: #ffdb99;
    color: #fff;
  }
  .bodyback() {
    background-image: @bgimage;
    background-repeat:repeat-x;

  }
  .fullback() {
    background-image: @bgcontentimage;
    background-repeat:repeat-x;
    background-position:center 0rem;
    background-size:30rem 47.9rem;
    height:45.9rem;
  }
  //color2
  @shoptitlecolor: #f71b00;
  @logoborder: 0.5rem solid #f71b00;
  @shopdesccolor: #227eb1;
  @homemsgcolor: #a91200;
  @mainfontcolor: #a91200;
  @thcolor: white;
  @activetabcolor: #dbaf34;
  @navbgcolor: none;
  @tabfontcolor: #000000;
  @hometxtcolor: #008e18;
  @shopbackgroundcolor: #fccb42;
  @successcolor: white;
  @buttoncolor: white;
  @buttonbgcolor: #f71b00;
  @wrenchimage: url(/images/shop/parts/ps2wrench2.png);
  @spinnerimage: url(/images/shop/shared/spinner-red.png) no-repeat;
  .navstyle() {
  color:#fff;
    background-color: none;
  line-height: 1.5rem;
  padding: 1.1rem 2rem;
  border:none;
  text-decoration:none;
  }
  .activestyle() {
    color:#fff;
  text-shadow: none;
  border:none;
  background: rgba(0, 0, 0, 0.3);
  }
  @import "../../shared.less";
  @import "./partsLayout2.less";
}

</style>
